@@ -13,7 +13,7 @@ package Device::SMBus;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 use 5.010000;
 
@@ -146,7 +146,7 @@ Device::SMBus - Perl interface for smbus using libi2c-dev library.
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -276,10 +276,18 @@ Shantanu Bhadoria <shantanu at cpan dott org>
 
 =item *
 
+Neil Bowers <neil@bowers.com>
+
+=item *
+
 Shantanu <shantanu@cpan.org>
 
 =item *
 
+Shantanu Bhadoria <shantanu.bhadoria@gmail.com>
+
+=item *
+
 Shantanu Bhadoria <shantanu@cpan.org>
 
 =back
